@@ -41,7 +41,10 @@ class ReferenceImage:
 
 
 class ReferenceImageConnector:
-    Context = HttpServerConnector.Context
+    @dataclass
+    class Context(HttpServerConnector.Context):
+        project_name: str
+
     Config = HttpServerConnector.Config
 
     def __init__(self, config: Config, context: Context):
@@ -67,13 +70,17 @@ class ReferenceImageConnector:
         if offset is not None:
             payload["offset"] = offset
 
-        answer = await self._connector.post_json("/entity/reference_image/get", payload)
+        answer = await self._connector.post_json("/entity/reference_image/get",
+                                                 payload=payload,
+                                                 headers=self._construct_headers())
         return [ReferenceImage(**reference_image) for reference_image in answer["result"]]
 
     async def get_reference_image_file_ids(self, stream_url: str, date: datetime) -> list[str]:
         payload = {"stream_url": stream_url, "iso_date": date.isoformat()}
 
-        answer = await self._connector.get("/reference_image/get", payload)
+        answer = await self._connector.get("/reference_image/get",
+                                           url_query=payload,
+                                           headers=self._construct_headers())
         return answer["result"]
 
     async def add_reference_image(self,
@@ -90,5 +97,10 @@ class ReferenceImageConnector:
         if weight_month_shift is not None:
             payload["weight_month_shift"] = weight_month_shift
 
-        answer = await self._connector.post_json("/reference_image/add", payload)
+        answer = await self._connector.post_json("/reference_image/add",
+                                                 payload=payload,
+                                                 headers=self._construct_headers())
         return answer["result"]
+
+    def _construct_headers(self) -> dict[str, str]:
+        return {"server_name": self.context.project_name}
